/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.extensions.validator.core.renderkit;

import org.apache.myfaces.extensions.validator.internal.UsageCategory;
import org.apache.myfaces.extensions.validator.internal.UsageInformation;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.faces.context.ResponseStream;
import javax.faces.context.ResponseWriter;
import javax.faces.render.RenderKit;
import javax.faces.render.Renderer;
import javax.faces.render.ResponseStateManager;
import javax.faces.render.ClientBehaviorRenderer;
import java.io.OutputStream;
import java.io.Writer;
import java.util.Iterator;

/**
 * @author Gerhard Petracek
 * @since 1.x.1
 */
@UsageInformation(UsageCategory.INTERNAL)
public class ExtValRenderKit extends RenderKit
{
    protected final Log logger = LogFactory.getLog(getClass());
    protected RenderKit wrapped;

    public ExtValRenderKit(RenderKit wrapped)
    {
        this.wrapped = wrapped;

        if(logger.isDebugEnabled())
        {
            logger.debug(getClass().getName() + " instantiated");
        }
    }

    public void addRenderer(String family, String rendererType, Renderer renderer)
    {
        if (renderer instanceof ExtValRendererWrapper)
        {
            wrapped.addRenderer(family, rendererType, renderer);
        }
        else
        {
            wrapped.addRenderer(family, rendererType, createWrapper(renderer));
        }
    }

    public Renderer getRenderer(String family, String rendererType)
    {
        Renderer renderer = wrapped.getRenderer(family, rendererType);

        if(renderer != null)
        {
            return renderer instanceof ExtValRendererWrapper ? renderer : createWrapper(renderer);
        }

        if(this.logger.isWarnEnabled())
        {
            this.logger.warn("no renderer found for family " + family + " and type " + rendererType);
        }

        return renderer;
    }

    public ResponseStateManager getResponseStateManager()
    {
        return wrapped.getResponseStateManager();
    }

    public ResponseWriter createResponseWriter(Writer writer, String s, String s1)
    {
        return wrapped.createResponseWriter(writer, s, s1);
    }

    public ResponseStream createResponseStream(OutputStream outputStream)
    {
        return wrapped.createResponseStream(outputStream);
    }

    public Iterator<String> getComponentFamilies()
    {
        return wrapped.getComponentFamilies();
    }

    public Iterator<String> getRendererTypes(String s)
    {
        return wrapped.getRendererTypes(s);
    }

    public void addClientBehaviorRenderer(String s, ClientBehaviorRenderer clientBehaviorRenderer)
    {
        wrapped.addClientBehaviorRenderer(s, clientBehaviorRenderer);
    }

    public ClientBehaviorRenderer getClientBehaviorRenderer(String s)
    {
        return wrapped.getClientBehaviorRenderer(s);
    }

    public Iterator<String> getClientBehaviorRendererTypes()
    {
        return wrapped.getClientBehaviorRendererTypes();
    }

    @UsageInformation(UsageCategory.REUSE)
    protected Renderer createWrapper(Renderer renderer)
    {
        return new ExtValRendererWrapper(renderer);
    }

}
